@@ -196,7 +196,7 @@ function goToggleToolbar( id, elementID )
   }
 }
 
-//@line 200 "/buildbot/comm-central-linux-nightly/build/mail/base/content/utilityOverlay.js"
+//@line 200 "/buildbot/linux-comm-1.9.2-nightly/build/mail/base/content/utilityOverlay.js"
 /**
  * Opens the update manager and checks for updates to the application.
  */
@@ -217,7 +217,7 @@ function checkForUpdates()
   else
     prompter.checkForUpdates();
 }
-//@line 221 "/buildbot/comm-central-linux-nightly/build/mail/base/content/utilityOverlay.js"
+//@line 221 "/buildbot/linux-comm-1.9.2-nightly/build/mail/base/content/utilityOverlay.js"
 
 /**
  * Set up the help menu software update items to show proper status,
@@ -225,10 +225,12 @@ function checkForUpdates()
  */
 function buildHelpMenu()
 {
-//@line 229 "/buildbot/comm-central-linux-nightly/build/mail/base/content/utilityOverlay.js"
+//@line 229 "/buildbot/linux-comm-1.9.2-nightly/build/mail/base/content/utilityOverlay.js"
   var updates =
       Components.classes["@mozilla.org/updates/update-service;1"].
-      getService(Components.interfaces.nsIApplicationUpdateService);
+//@line 232 "/buildbot/linux-comm-1.9.2-nightly/build/mail/base/content/utilityOverlay.js"
+      getService(Components.interfaces.nsIApplicationUpdateService2);
+//@line 236 "/buildbot/linux-comm-1.9.2-nightly/build/mail/base/content/utilityOverlay.js"
   var um =
       Components.classes["@mozilla.org/updates/update-manager;1"].
       getService(Components.interfaces.nsIUpdateManager);
@@ -236,9 +238,9 @@ function buildHelpMenu()
   // Disable the UI if the update enabled pref has been locked by the
   // administrator or if we cannot update for some other reason.
   var checkForUpdates = document.getElementById("checkForUpdates");
-  var canUpdate = updates.canUpdate;
-  checkForUpdates.setAttribute("disabled", !canUpdate);
-  if (!canUpdate)
+  var canCheckForUpdates = updates.canCheckForUpdates;
+  checkForUpdates.setAttribute("disabled", !canCheckForUpdates);
+  if (!canCheckForUpdates)
     return;
 
   var strings = document.getElementById("bundle_messenger");
@@ -283,7 +285,7 @@ function buildHelpMenu()
     checkForUpdates.setAttribute("loading", "true");
   else
     checkForUpdates.removeAttribute("loading");
-//@line 299 "/buildbot/comm-central-linux-nightly/build/mail/base/content/utilityOverlay.js"
+//@line 303 "/buildbot/linux-comm-1.9.2-nightly/build/mail/base/content/utilityOverlay.js"
 }
 
 // openUILink handles clicks on UI elements that cause URLs to load.
@@ -329,19 +331,18 @@ function openContentTab(url)
                         tabParams: {contentPage: url} });
 }
 
-function openFeatureConfigurator() {
-  let mail3PaneWindow = Components.classes["@mozilla.org/appshell/window-mediator;1"]
-                                  .getService(Components.interfaces.nsIWindowMediator)
-                                  .getMostRecentWindow("mail:3pane");
-  const url = "chrome://messenger/content/featureConfigurator.xhtml";
-  if (mail3PaneWindow) {
-    mail3PaneWindow.focus();
-    mail3PaneWindow.document.getElementById("tabmail")
-                            .openTab("chromeTab", {chromePage: url});
-  } else {
-    window.openDialog("chrome://messenger/content/", "_blank",
-                      "chrome,dialog=no,all", null,
-                      { tabType: "chromeTab",
-                        tabParams: {chromePage: url} });
-  }
+/**
+ * Open the Migration Assistant.
+ *
+ * @param aIsUpgrade whether this is being opened as a result of upgrading
+ *     from an earlier version of Thunderbird.
+ */
+function openFeatureConfigurator(aIsUpgrade) {
+  let options = "chrome,dialog=yes,all,centerscreen,width=704,height=416";
+  if (aIsUpgrade)
+    options += ",modal";
+  window.openDialog("chrome://messenger/content/featureConfigurator.xhtml",
+                    "_blank", options,
+                    // Below are window.arguments for featureConfigurator.js
+                    window, aIsUpgrade);
 }
