@@ -166,12 +166,14 @@ pref("gfx.downloadable_fonts.sanitize", true);
 pref("gfx.downloadable_fonts.sanitize.preserve_otl_tables", true);
 //@line 178 "/buildbot/linux-comm-1.9.2-nightly/build/mozilla/modules/libpref/src/init/all.js"
 
+//@line 186 "/buildbot/linux-comm-1.9.2-nightly/build/mozilla/modules/libpref/src/init/all.js"
+
 pref("accessibility.browsewithcaret", false);
 pref("accessibility.warn_on_browsewithcaret", true);
 
 pref("accessibility.browsewithcaret_shortcut.enabled", true);
 
-//@line 185 "/buildbot/linux-comm-1.9.2-nightly/build/mozilla/modules/libpref/src/init/all.js"
+//@line 193 "/buildbot/linux-comm-1.9.2-nightly/build/mozilla/modules/libpref/src/init/all.js"
 // Tab focus model bit field:
 // 1 focuses text controls, 2 focuses other form elements, 4 adds links.
 // Most users will want 1, 3, or 7.
@@ -184,7 +186,7 @@ pref("accessibility.tabfocus_applies_to_xul", false);
 // unless this preference was set manually
 pref("ui.scrollToClick", 0);
 
-//@line 201 "/buildbot/linux-comm-1.9.2-nightly/build/mozilla/modules/libpref/src/init/all.js"
+//@line 209 "/buildbot/linux-comm-1.9.2-nightly/build/mozilla/modules/libpref/src/init/all.js"
 
 pref("accessibility.usetexttospeech", "");
 pref("accessibility.usebrailledisplay", "");
@@ -528,9 +530,9 @@ pref("dom.storage.enabled", true);
 pref("dom.storage.default_quota",      5120);
 
 // Parsing perf prefs. For now just mimic what the old code did.
-//@line 545 "/buildbot/linux-comm-1.9.2-nightly/build/mozilla/modules/libpref/src/init/all.js"
+//@line 553 "/buildbot/linux-comm-1.9.2-nightly/build/mozilla/modules/libpref/src/init/all.js"
 pref("content.sink.pending_event_mode", 0);
-//@line 547 "/buildbot/linux-comm-1.9.2-nightly/build/mozilla/modules/libpref/src/init/all.js"
+//@line 555 "/buildbot/linux-comm-1.9.2-nightly/build/mozilla/modules/libpref/src/init/all.js"
 
 // Disable popups from plugins by default
 //   0 = openAllowed
@@ -579,7 +581,7 @@ pref("network.protocol-handler.external.data", false);
 pref("network.protocol-handler.external.ms-help", false);
 pref("network.protocol-handler.external.shell", false);
 pref("network.protocol-handler.external.vnd.ms.radio", false);
-//@line 598 "/buildbot/linux-comm-1.9.2-nightly/build/mozilla/modules/libpref/src/init/all.js"
+//@line 606 "/buildbot/linux-comm-1.9.2-nightly/build/mozilla/modules/libpref/src/init/all.js"
 pref("network.protocol-handler.external.disk", false);
 pref("network.protocol-handler.external.disks", false);
 pref("network.protocol-handler.external.afp", false);
@@ -724,6 +726,7 @@ pref("network.IDN.whitelist.kr", true);
 pref("network.IDN.whitelist.li", true);
 pref("network.IDN.whitelist.lt", true);
 pref("network.IDN.whitelist.lu", true);
+pref("network.IDN.whitelist.lv", true);
 pref("network.IDN.whitelist.no", true);
 pref("network.IDN.whitelist.nu", true);
 pref("network.IDN.whitelist.nz", true);
@@ -734,6 +737,7 @@ pref("network.IDN.whitelist.sh", true);
 pref("network.IDN.whitelist.th", true);
 pref("network.IDN.whitelist.tm", true);
 pref("network.IDN.whitelist.tw", true);
+pref("network.IDN.whitelist.ua", true);
 pref("network.IDN.whitelist.vn", true);
 
 // IDN ccTLDs
@@ -742,6 +746,8 @@ pref("network.IDN.whitelist.xn--mgbaam7a8h", true);
 // cn, China, .<China> with variants
 pref("network.IDN.whitelist.xn--fiqz9s", true); // Traditional
 pref("network.IDN.whitelist.xn--fiqs8s", true); // Simplified
+// eg, Egypt, .<Masr>
+pref("network.IDN.whitelist.xn--wgbh1c", true);
 // hk, Hong Kong, .<Hong Kong>
 pref("network.IDN.whitelist.xn--j6w193g", true);
 // ir, Iran, <.Iran> with variants
@@ -749,6 +755,9 @@ pref("network.IDN.whitelist.xn--mgba3a4f16a", true);
 pref("network.IDN.whitelist.xn--mgba3a4fra", true);
 // jo, Jordan, .<Al-Ordon>
 pref("network.IDN.whitelist.xn--mgbayh7gpa", true);
+// lk, Sri Lanka, .<Lanka> and .<Ilangai>
+pref("network.IDN.whitelist.xn--fzc2c9e2c", true);
+pref("network.IDN.whitelist.xn--xkc2al3hye2a", true);
 // qa, Qatar, .<Qatar>
 pref("network.IDN.whitelist.xn--wgbl6a", true);
 // ru, Russian Federation, .<RF>
@@ -758,11 +767,14 @@ pref("network.IDN.whitelist.xn--mgberp4a5d4ar", true);
 pref("network.IDN.whitelist.xn--mgberp4a5d4a87g", true);
 pref("network.IDN.whitelist.xn--mgbqly7c0a67fbc", true);
 pref("network.IDN.whitelist.xn--mgbqly7cvafr", true);
+// sy, Syria, .<Souria>
+pref("network.IDN.whitelist.xn--ogbpf8fl", true);
 // tw, Taiwan, <.Taiwan> with variants
 pref("network.IDN.whitelist.xn--kpry57d", true);  // Traditional
 pref("network.IDN.whitelist.xn--kprw13d", true);  // Simplified
 
 // gTLDs
+pref("network.IDN.whitelist.asia", true);
 pref("network.IDN.whitelist.biz", true);
 pref("network.IDN.whitelist.cat", true);
 pref("network.IDN.whitelist.info", true);
@@ -848,7 +860,7 @@ pref("network.negotiate-auth.gsslib", "");
 // Specify if the gss lib comes standard with the OS
 pref("network.negotiate-auth.using-native-gsslib", true);
 
-//@line 872 "/buildbot/linux-comm-1.9.2-nightly/build/mozilla/modules/libpref/src/init/all.js"
+//@line 890 "/buildbot/linux-comm-1.9.2-nightly/build/mozilla/modules/libpref/src/init/all.js"
 
 // Controls which NTLM authentication implementation we default to. True forces
 // the use of our generic (internal) NTLM authentication implementation vs. any
@@ -1269,15 +1281,15 @@ pref("font.minimum-size.x-western", 0);
 pref("font.minimum-size.x-unicode", 0);
 pref("font.minimum-size.x-user-def", 0);
 
-//@line 1690 "/buildbot/linux-comm-1.9.2-nightly/build/mozilla/modules/libpref/src/init/all.js"
+//@line 1708 "/buildbot/linux-comm-1.9.2-nightly/build/mozilla/modules/libpref/src/init/all.js"
 
-//@line 2114 "/buildbot/linux-comm-1.9.2-nightly/build/mozilla/modules/libpref/src/init/all.js"
+//@line 2132 "/buildbot/linux-comm-1.9.2-nightly/build/mozilla/modules/libpref/src/init/all.js"
 
-//@line 2317 "/buildbot/linux-comm-1.9.2-nightly/build/mozilla/modules/libpref/src/init/all.js"
+//@line 2335 "/buildbot/linux-comm-1.9.2-nightly/build/mozilla/modules/libpref/src/init/all.js"
 
-//@line 2413 "/buildbot/linux-comm-1.9.2-nightly/build/mozilla/modules/libpref/src/init/all.js"
+//@line 2431 "/buildbot/linux-comm-1.9.2-nightly/build/mozilla/modules/libpref/src/init/all.js"
 
-//@line 2416 "/buildbot/linux-comm-1.9.2-nightly/build/mozilla/modules/libpref/src/init/all.js"
+//@line 2434 "/buildbot/linux-comm-1.9.2-nightly/build/mozilla/modules/libpref/src/init/all.js"
 // Handled differently under Mac/Windows
 pref("network.hosts.smtp_server", "localhost");
 pref("network.hosts.pop_server", "pop");
@@ -1547,15 +1559,15 @@ pref("ui.panel.default_level_parent", true);
 
 pref("mousewheel.system_scroll_override_on_root_content.enabled", false);
 
-//@line 2688 "/buildbot/linux-comm-1.9.2-nightly/build/mozilla/modules/libpref/src/init/all.js"
+//@line 2706 "/buildbot/linux-comm-1.9.2-nightly/build/mozilla/modules/libpref/src/init/all.js"
 
-//@line 2756 "/buildbot/linux-comm-1.9.2-nightly/build/mozilla/modules/libpref/src/init/all.js"
+//@line 2774 "/buildbot/linux-comm-1.9.2-nightly/build/mozilla/modules/libpref/src/init/all.js"
 
-//@line 2782 "/buildbot/linux-comm-1.9.2-nightly/build/mozilla/modules/libpref/src/init/all.js"
+//@line 2800 "/buildbot/linux-comm-1.9.2-nightly/build/mozilla/modules/libpref/src/init/all.js"
 
-//@line 2802 "/buildbot/linux-comm-1.9.2-nightly/build/mozilla/modules/libpref/src/init/all.js"
+//@line 2820 "/buildbot/linux-comm-1.9.2-nightly/build/mozilla/modules/libpref/src/init/all.js"
 
-//@line 2810 "/buildbot/linux-comm-1.9.2-nightly/build/mozilla/modules/libpref/src/init/all.js"
+//@line 2828 "/buildbot/linux-comm-1.9.2-nightly/build/mozilla/modules/libpref/src/init/all.js"
 
 // Login Manager prefs
 pref("signon.rememberSignons",              true);
@@ -1592,9 +1604,9 @@ pref("image.cache.timeweight", 500);
 // The default Accept header sent for images loaded over HTTP(S)
 pref("image.http.accept", "image/png,image/*;q=0.8,*/*;q=0.5");
 
-//@line 2852 "/buildbot/linux-comm-1.9.2-nightly/build/mozilla/modules/libpref/src/init/all.js"
+//@line 2870 "/buildbot/linux-comm-1.9.2-nightly/build/mozilla/modules/libpref/src/init/all.js"
 
-//@line 2857 "/buildbot/linux-comm-1.9.2-nightly/build/mozilla/modules/libpref/src/init/all.js"
+//@line 2875 "/buildbot/linux-comm-1.9.2-nightly/build/mozilla/modules/libpref/src/init/all.js"
 
 // Enable/Disable the geolocation API for content
 pref("geo.enabled", true);
