@@ -1,7 +1,7 @@
-//@line 42 "/buildbot/comm-central-linux-nightly/build/mail/components/addrbook/content/addressbook.js"
+//@line 42 "/buildbot/linux-comm-1.9.2-nightly/build/mail/components/addrbook/content/addressbook.js"
 
 // Ensure the activity modules are loaded for this window.
-Components.utils.import("resource://app/modules/activity/activityModules.js");
+Components.utils.import("resource:///modules/activity/activityModules.js");
 
 const nsIAbListener = Components.interfaces.nsIAbListener;
 const kPrefMailAddrBookLastNameFirst = "mail.addr_book.lastnamefirst";
