@@ -1,4 +1,4 @@
-//@line 38 "/buildbot/comm-central-linux-nightly/build/mail/base/content/hiddenWindow.js"
+//@line 38 "/buildbot/linux-comm-1.9.2-nightly/build/mail/base/content/hiddenWindow.js"
 
 // XXX This is needed by mailCommands.js for the new message command, ideally
 // this shouldn't be a global.
@@ -23,7 +23,8 @@ function hiddenWindowStartup()
              'goNextMenu', 'menu_nextMsg', 'menu_nextUnreadMsg', 'menu_nextUnreadThread',
              'goPreviousMenu', 'menu_prevMsg', 'menu_prevUnreadMsg', 'menu_goForward', 'menu_goBack',
              'goStartPage', 'newMsgCmd', 'replyMainMenu', 'replySenderMainMenu', 'replyNewsgroupMainMenu',
-             'menu_replyToAll', 'menu_replyToList', 'menu_forwardMsg', 'forwardAsMenu', 'menu_editMsgAsNew', 'openMessageWindowMenuitem',
+             'menu_replyToAll', 'menu_replyToList', 'menu_forwardMsg', 'forwardAsMenu', 'menu_editMsgAsNew',
+             'openMessageWindowMenuitem', 'openConversationMenuitem',
              'moveMenu', 'copyMenu', 'moveToFolderAgain', 'tagMenu', 'markMenu',
              'markReadMenuItem', 'menu_markThreadAsRead', 'menu_markReadByDate', 'menu_markAllRead',
              'markFlaggedMenuItem', 'menu_markAsJunk', 'menu_markAsNotJunk', 'createFilter',
